<p align="center">
  <br>
  <a href="#">
    <img src="" width="100" alt="Mersad Cryptography Library"/>
  </a>
</p>

<h1 align="center">Mersad Cryptography Library</h1>
<h3 align="center">A toy project by a lonely student who likes ciphers.</h3>
<p align="center">

<p align="center">
  <a title="Open Source" href="https://opensource.com/resources/what-open-source" target="_blank">
    <img src="https://img.shields.io/badge/Open%20Source-Forever-brightgreen?logo=open-source-initiative&style=flat-square" alt="Open Source">
  </a>
  <a title="License: AGPL-3.0" href="https://www.opensource.org/licenses/AGPL-3.0" target="_blank">
    <img src="https://img.shields.io/github/license/azadeh-afzar/Mersad-Cryptography-Library?logo=gnu&style=flat-square" alt="License: AGPL v3">
  </a>
  <a title="Language counter" href="" target="_blank">
    <img src="https://img.shields.io/github/languages/count/azadeh-afzar/Mersad-Cryptography-Library?logo=gitlab&style=flat-square" alt="Language counter">
  </a>
  <a title="Top language" href="" target="_blank">
    <img src="https://img.shields.io/github/languages/top/azadeh-afzar/Mersad-Cryptography-Library?logo=gitlab&style=flat-square" alt="Top language">
  </a>
  <a title="PyPi: version support" href="https://pypi.org/project/Mersad" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/Mersad?logo=pypi&style=flat-square" alt="Supported Python versions">
  </a>
  <a title="PyPi: Mersad version" href="https://pypi.org/project/Mersad" target="_blank">
    <img src="https://img.shields.io/pypi/v/Mersad?logo=pypi&style=flat-square" alt="PyPI version">
  </a>
  <a title="PyPi: Mersad downloads" href="https://pypi.org/project/Mersad" target="_blank">
    <img src="https://img.shields.io/pypi/dm/Mersad?logo=pypi&style=flat-square" alt="PyPI downloads">
  </a>

  
  <br>
  
  <a title="Code Quality: Codefactor.io" href="https://www.codefactor.io/repository/github/azadeh-afzar/mersad-cryptography-library" target="_blank">
    <img src="https://www.codefactor.io/repository/github/azadeh-afzar/mersad-cryptography-library/badge?style=flat-square" alt="CodeFactor"/>
  </a>
  <a title="Code Quality: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library/maintainability" target="_blank">
    <img src="https://img.shields.io/codeclimate/maintainability/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate rating"/>
  </a>
  <a title="Code Quality: Scrutinizer-ci.com" href="https://scrutinizer-ci.com/g/azadeh-afzar/Mersad-Cryptography-Library/?branch=master" target="_blank">
    <img src="https://img.shields.io/scrutinizer/quality/g/azadeh-afzar/Mersad-Cryptography-Library/master?logo=scrutinizer&style=flat-square" alt="Scrutinizer-ci rating"/>
  </a>
  <a title="Code Technical Debt: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library/maintainability" target="_blank">
    <img src="https://img.shields.io/codeclimate/tech-debt/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate technical debt"/>
  </a>
  <a title="Code Issues: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library/maintainability" target="_blank">
    <img src="https://img.shields.io/codeclimate/issues/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate issues"/>
  </a>
  
  <br>
  <a title="GitLab: pipeline status" href="https://gitlab.com/Azadeh-Afzar/Cryptography/Mersad-Cryptography-Library/commits/master" target="_blank">
    <img src="https://img.shields.io/gitlab/pipeline/Cryptography/Mersad-Cryptography-Library?gitlab_url=https%3A%2F%2Fgitlab.com%2FAzadeh-Afzar&logo=gitlab&style=flat-square"  alt="pipeline status" />
  </a>
  <a title="Travis CI: build status" href="https://gitlab.com/Azadeh-Afzar/Cryptography/Mersad-Cryptography-Library/commits/master" target="_blank">
    <img src="https://img.shields.io/travis/azadeh-afzar/Mersad-Cryptography-Library/master?logo=travis&style=flat-square"  alt="travis build status" />
  </a>
  <a title="Test Coverage: CodeClimate.com" href="https://codeclimate.com/github/azadeh-afzar/Mersad-Cryptography-Library" target="_blank">
    <img src="https://img.shields.io/codeclimate/coverage/azadeh-afzar/Mersad-Cryptography-Library?logo=code-climate&style=flat-square" alt="CodeClimate"/>
  </a>
  
</p>


### LOL what is CRYPTO?

### Edwarx snowden?

## Quick start


### Customizing

## How it works


### Notes


## Contribution

If you want to contribute to this project, please read [CONTRIBUTING](CONTRIBUTING.md).

## Code of Conduct

Visit the [Code of Conduct](CODE_OF_CONDUCT.md).

## Roadmap

Visit the [Roadmap](ROADMAP.md) to keep track of which features we are currently working on.

## License

Licensed under the [AGPLv3](LICENSE).

## Attribution

